import type { App } from 'vue';
import { useUserInfo } from '@/stores/userInfo';
import { judgementSameArr } from '@/utils/arrayOperation';
import { nextTick } from 'vue';

/**
 * 用户权限指令
 * @directive 单个权限验证（v-auth="xxx"）
 * @directive 多个权限验证，满足一个则显示（v-auths="[xxx,xxx]"）
 * @directive 多个权限验证，全部满足则显示（v-auth-all="[xxx,xxx]"）
 */
export function authDirective(app: App) {
	// 单个权限验证（v-auth="xxx"）
	app.directive('auth', {
		mounted(el, binding) {
			const stores = useUserInfo();
			nextTick(() => {
				const hasPermission = stores.userInfos.authBtnList?.some((v: string) => v === binding.value);
				if (!hasPermission) {
					// ✅ 更安全的做法，确保父节点存在且包含 el
					const parent = el.parentNode;
					if (parent && parent.contains(el)) {
						parent.removeChild(el);
					}
				}
			}).then();
		}
	});
	// 多个权限验证，满足一个则显示（v-auths="[xxx,xxx]"）
	app.directive('auths', {
		mounted(el, binding) {
			if (!binding.value) {
				el.parentNode && el.parentNode.removeChild(el);
			}
			let flag = false;
			const stores = useUserInfo();
			stores.userInfos.authBtnList?.map((val: string) => {
				binding.value.map((v: string) => {
					if (val === v) flag = true;
				});
			});
			if (!flag) el.parentNode.removeChild(el);
		},
	});
	// 多个权限验证，全部满足则显示（v-auth-all="[xxx,xxx]"）
	app.directive('auth-all', {
		mounted(el, binding) {
			if (!binding.value) {
				el.parentNode && el.parentNode.removeChild(el);
			}
			const stores = useUserInfo();
			const flag = judgementSameArr(binding.value, stores.userInfos.authBtnList);
			if (!flag) el.parentNode.removeChild(el);
		},
	});
}
